<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'Icredit_Admin_Docs' ) ) {
	/**
	 * Checked for WooCommerce Version 4.7
	 *
	 * Provides a iCredit Payment Gateway.
	 *
	 * @class        Icredit_Admin_Docs
	 */
	class Icredit_Admin_Docs {
		private static $instance = null;
		private $key;

		/**
		 * Icredit_Admin_Fields_Paypal __construct
		 */
		public function __construct() {
			add_action( 'add_meta_boxes', array( $this, 'icredit_doc_admin_order_page_metabox' ) );
		}

		/**
		 * @return void
		 * security reasons
		 */
		private function __clone() {
		}

		/**
		 * @return Icredit_Admin_Docs|null
		 */
		public static function getInstance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}


		/**
		 * @return void
		 */
		public function icredit_doc_admin_order_page_metabox() {
			add_meta_box(
				'icredit_order_payment_details_docs',
				__( 'Icredit order Documents details', 'woocommerce_icredit_paypal' ),
				array( $this, 'icredit_order_payment_details_docs_callback' ),
				'shop_order',
				'side',
				'high'
			);
		}

		/**
		 * @return void
		 */
		public function icredit_order_payment_details_docs_callback() {
			global $post;
			$keys      = ['rivhit_document_url', 'rivhit_receipt_url'];
			$meta_data = $this->get_meta_data_for_keys( $post->ID, $keys );
			$title_documents = __( 'Documents', 'woocommerce_icredit_paypal' );

			$template = '<div id="metaboxRivhitDoc"><div class="metaboxRivhitInner"><figure><img class="icon_rivhit" width="150" height="60" src="' . plugin_dir_url( __FILE__ ) . '../assets/images/Rivhit2.png' . '" alt="rivhit icredit" aria-label="logo rivhit icredit" /></figure>';
			$template .= '<div class="rivhitSectionFirst">';
			$template .= '<h3>' . $title_documents . '</h3>';
			if ( ! empty( $meta_data['rivhit_document_url'] ) ) {
				$template .= '<a id="" target="_blank" data-tip="' . __( 'Print Invoice', 'woocommerce_icredit_paypal' ) . '" class="button tips invoice-button-small " href="' . $meta_data['rivhit_document_url'] . '">';
				$template .= __( 'Print Invoice', 'woocommerce_icredit_paypal' );
				$template .= '</a>';
			}
			if ( ! empty( $meta_data['rivhit_receipt_url'] ) ) {
				$template .= '<a id="" target="_blank" data-tip="' . __( 'Print Receipt', 'woocommerce_icredit_paypal' ) . '" class="button tips invoice-button-small " href="' . $meta_data['rivhit_receipt_url'] . '">';
				$template .= __( 'Print Receipt', 'woocommerce_icredit_paypal' );
				$template .= '</a>';
			}
			$template .= '</div></div></div>';
			echo $template;
		}

		/**
		 * @param $order_id
		 * @param $keys
		 *
		 * @return array
		 */
		private function get_meta_data_for_keys( $order_id, $keys = array() ) {
			$arr = [];
			global $wpdb;
			$sql = "SELECT m.meta_key, m.meta_value FROM `$wpdb->posts` AS p RIGHT JOIN `$wpdb->postmeta` AS m ON (p.ID = m.post_id) WHERE p.post_type = 'shop_order' AND p.ID = $order_id AND ";
			if ( ! empty( $keys ) ) {
				$sql .= " (SELECT ";
				foreach ( $keys as $l => $k ) {
					$or = ' OR ';
					if ( $l == 0 ) {
						$or = '';
					}
					$sql .= $or . " meta_key = '$k' ";;
				}
				$sql .= " )";
			}
			$rows = $wpdb->get_results( $sql );
			if ( ! empty( $rows ) ) {
				foreach ( $rows as $row ) {
					$arr[ $row->meta_key ] = $row->meta_value;
				}
			}

			return $arr;
		}

	}

	$self_class_icredit_paypal_Admin = Icredit_Admin_Docs::getInstance();
}
