<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'Icredit_Admin_Fields_Paypal' ) ) {
	/**
	 * Checked for WooCommerce Version 4.7
	 *
	 * Provides a iCredit Payment Gateway.
	 *
	 * @class        Icredit_Admin_Fields_Paypal
	 */
	class Icredit_Admin_Fields_Paypal {
		private static $instance = null;
		private $key;

		/**
		 * Icredit_Admin_Fields_Paypal __construct
		 */
		public function __construct() {
			$this->key = 'paypal_icredit_action_key';
		}

		/**
		 * @return void
		 * security reasons
		 */
		private function __clone() {
		}

		/**
		 * @return Icredit_Admin_Fields_Paypal|null
		 */
		public static function getInstance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * @param $hook
		 *
		 * @return void
		 *
		 * add admin scripts
		 */
		public static function rivhit_paypal_admin_enqueue( $hook ) {
			$version = RIVHIT_PAYPAL_VERSION;
			wp_enqueue_style( 'admin-css-paypal-icredit', plugin_dir_url( __FILE__ ) . '../assets/css/woocommerce-icredit.css', array(), $version );
		}

		/**
		 * @return mixed
		 *
		 * PayPal Icretid extension fields
		 */
		public function paypal_fields_extension() {
			$options = $this->get_paypal_options();
			if ( empty( $options['paypal_receipt_type'] ) ) {
				$options['paypal_receipt_type'] = 0;
			}
			if ( empty( $options['paypal_document_type'] ) && $options['paypal_document_type'] != 0 && $options['paypal_document_type'] != '0' ) {
				$options['paypal_document_type'] = 2;
			}
			return array(
				'handle_paypal_ipn'       => array(
					'title'   => __( 'Handle PayPal IPN/Webhook', 'woocommerce_icredit_paypal' ),
					'type'    => 'checkbox',
					'label'   => __( 'Check this if you wish to create iCredit invoices for orders that completed successfuly with PayPal payment', 'woocommerce_icredit_paypal' ),
					'default' => $options['handle_paypal_ipn'] ? $options['handle_paypal_ipn'] : '1',
				),
				'paypal_api_token'        => array(
					'title'   => __( 'API Token', 'woocommerce_icredit_paypal' ),
					'type'    => 'text',
					'default' => $options['paypal_api_token'],
				),
				'paypal_receipt_type'     => array(
					'title'       => __( 'Receipt Type', 'woocommerce_icredit_paypal' ),
					'type'        => 'text',
					'default'     => $options['paypal_receipt_type'],
					'description' => '',
				),
				'paypal_document_type'    => array(
					'title'       => __( 'Document Type', 'woocommerce_icredit_paypal' ),
					'type'        => 'text',
					'default'     => $options['paypal_document_type'],
					'description' => '',
				),
				'paypal_customer_id'      => array(
					'title'   => __( 'Customer ID', 'woocommerce_icredit_paypal' ),
					'type'    => 'text',
					'default' => $options['paypal_customer_id'] ? $options['paypal_customer_id'] : '0',
				),
				'paypal_sort_code'        => array(
					'title'   => __( 'Sort Code', 'woocommerce_icredit_paypal' ),
					'type'    => 'text',
					'default' => $options['paypal_sort_code'] ? $options['paypal_sort_code'] : '100',
				),
				'paypal_exempt_sort_code' => array(
					'title'   => __( 'Exempt Sort Code', 'woocommerce_icredit_paypal' ),
					'type'    => 'text',
					'default' => $options['paypal_exempt_sort_code'] ? $options['paypal_exempt_sort_code'] : '150',
				),
				'paypal_rivpayment_type'  => array(
					'title'   => __( 'Rivhit Payment Type', 'woocommerce_icredit_paypal' ),
					'type'    => 'text',
					'default' => $options['paypal_rivpayment_type'] ? $options['paypal_rivpayment_type'] : '10',
				),
				'bcc_email'               => array(
					'title'       => __( 'bcc email', 'woocommerce_icredit' ),
					'type'        => 'email',
					//'description' => __( 'send the rivhit invoice also to this email (bcc)', 'woocommerce_icredit_paypal' ),
					'description' => '',
					'desc_tip'    => false,
					'default'     => $options['bcc_email'] ? $options['bcc_email'] : '',
				),
				'paypal_send_mail'        => array(
					'title'   => __( 'Send Mail', 'woocommerce_icredit_paypal' ),
					'type'    => 'select',
					'options' => array(
						'true'  => __( 'True', 'woocommerce_icredit_paypal' ),
						'false' => __( 'False', 'woocommerce_icredit_paypal' )
					),
					'default' => $options['paypal_send_mail'] ? $options['paypal_send_mail'] : 'true',
				),
				'paypal_create_customer'  => array(
					'title'   => __( 'Create Customer', 'woocommerce_icredit_paypal' ),
					'type'    => 'select',
					'options' => array(
						'true'  => __( 'True', 'woocommerce_icredit_paypal' ),
						'false' => __( 'False', 'woocommerce_icredit_paypal' )
					),
					'default' => $options['paypal_create_customer'] ? $options['paypal_create_customer'] : 'true',
				),
				'use_shipping_fields' => array(
					'title'       => __( 'Order Address', 'woocommerce_icredit_paypal' ),
					'type'        => 'select',
					'description' => __( '* Choose which address will appear on the document/receipt', 'woocommerce_icredit_paypal' ),
					'options'     => array(
						'no'  => __( 'Billing Address', 'woocommerce_icredit_paypal' ),
						'yes' => __( 'Shipping Address', 'woocommerce_icredit_paypal' ),
					),
					'default' => $options['use_shipping_fields'] ? $options['use_shipping_fields'] : 'no',
					'desc_tip'    => true,
				),
				'document_language'       => array(
					'title'   => __( 'Document language', 'woocommerce_icredit_paypal' ),
					'type'    => 'select',
					'options' => array(
						'by_country_code' => __( 'By Country Code', 'woocommerce_icredit_paypal' ),
						'he'              => __( 'Hebrew', 'woocommerce_icredit_paypal' ),
						'en'              => __( 'English', 'woocommerce_icredit_paypal' ),
					),
					'default' => $options['document_language'],
				),
				'do_logging'              => array(
					'title'       => __( 'Logs for request document/receipt', 'woocommerce_icredit_paypal' ),
					'type'    => 'select',
					'options' => array(
						'yes'             => __( 'yes', 'woocommerce_icredit_paypal' ),
						'no'              => __( 'no', 'woocommerce_icredit_paypal' ),
					),
					'default' => $options['do_logging'],
				),
			);
		}

		/**
		 * @return void
		 */
		public function save_options( $data ) {
			$updatedData = [];
			if ( isset( $data['handle_paypal_ipn'] ) ) {
				$updatedData['handle_paypal_ipn'] = htmlentities( trim( $data['handle_paypal_ipn'] ) );
			}
			if ( isset( $data['paypal_api_token'] ) ) {
				$updatedData['paypal_api_token'] = htmlentities( trim( $data['paypal_api_token'] ) );
			}
			if ( isset( $data['paypal_document_type'] ) ) {
				if ( $data['paypal_document_type'] == 0 ) {
					$data['paypal_document_type'] = '0';
				}
				$updatedData['paypal_document_type'] = htmlentities( trim( $data['paypal_document_type'] ) );
			}
			if ( isset( $data['paypal_receipt_type'] ) ) {
				if ( $data['paypal_receipt_type'] == 0 ) {
					$data['paypal_receipt_type'] = '0';
				}
				$updatedData['paypal_receipt_type'] = htmlentities( trim( $data['paypal_receipt_type'] ) );
			}
			if ( isset( $data['paypal_customer_id'] ) ) {
				$updatedData['paypal_customer_id'] = htmlentities( trim( $data['paypal_customer_id'] ) );
			}
			if ( isset( $data['paypal_sort_code'] ) ) {
				$updatedData['paypal_sort_code'] = htmlentities( trim( $data['paypal_sort_code'] ) );
			}
			if ( isset( $data['paypal_exempt_sort_code'] ) ) {
				$updatedData['paypal_exempt_sort_code'] = htmlentities( trim( $data['paypal_exempt_sort_code'] ) );
			}
			if ( isset( $data['paypal_rivpayment_type'] ) ) {
				$updatedData['paypal_rivpayment_type'] = htmlentities( trim( $data['paypal_rivpayment_type'] ) );
			}
			if ( isset( $data['paypal_sign_pin'] ) ) {
				$updatedData['paypal_sign_pin'] = htmlentities( trim( $data['paypal_sign_pin'] ) );
			}
			if ( isset( $data['paypal_send_mail'] ) ) {
				$updatedData['paypal_send_mail'] = htmlentities( trim( $data['paypal_send_mail'] ) );
			}
			if ( isset( $data['paypal_create_customer'] ) ) {
				$updatedData['paypal_create_customer'] = htmlentities( trim( $data['paypal_create_customer'] ) );
			}
			if ( isset( $data['bcc_email'] ) ) {
				$updatedData['bcc_email'] = htmlentities( trim( $data['bcc_email'] ) );
			}
			if ( isset( $data['document_language'] ) ) {
				$updatedData['document_language'] = htmlentities( trim( $data['document_language'] ) );
			}
			if ( isset( $data['do_logging'] ) ) {
				$updatedData['do_logging'] = htmlentities( trim( $data['do_logging'] ) );
			}
			if ( isset( $data['use_shipping_fields'] ) ) {
				$updatedData['use_shipping_fields'] = htmlentities( trim( $data['use_shipping_fields'] ) );
			}
			update_option( $this->key, $updatedData );
		}

		/**
		 * @return mixed
		 */
		public function get_paypal_options() {
			$options = get_option( $this->key );
			if ( !$options ) {
				$options = [];
			}

			return $options;
		}


	}
}
