<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

if ( ! class_exists( 'WC_Gateway_ICredit_Paypal' ) ) {
	/**
	 * iCredit Payment Gateway
	 * Checked for WooCommerce Version 4.7
	 *
	 * Provides a iCredit Payment Gateway.
	 *
	 * @class        WC_Gateway_ICredit_Paypal
	 * @extends        WC_Gateway_ICredit
	 */
	class WC_Gateway_ICredit_Paypal {
		private static $instance = null;
		private
			$handle_paypal_ipn,
			$paypal_api_token,
			$paypal_document_type,
			$paypal_receipt_type,
			$paypal_customer_id,
			$paypal_sort_code,
			$paypal_exempt_sort_code,
			$paypal_rivpayment_type,
			$paypal_sign_pin,
			$paypal_send_mail,
			$paypal_create_customer,
			$paypal_which_docs_create,
			$bcc_email,
			$language,
			$logging,
			$end_points,
			$use_shipping_fields;

		public
			$logger = null;

		/**
		 * WC_Gateway_ICredit_Paypal __construct
		 */
		public function __construct() {
			$key     = 'paypal_icredit_action_key';
			$options = get_option( $key );

			$this->handle_paypal_ipn       = isset( $options['handle_paypal_ipn'] ) ? $options['handle_paypal_ipn'] : '';
			$this->paypal_api_token        = isset( $options['paypal_api_token'] ) ? $options['paypal_api_token'] : '';
			$this->paypal_document_type    = isset( $options['paypal_document_type'] ) ? $options['paypal_document_type'] : '2';
			$this->paypal_receipt_type     = isset( $options['paypal_receipt_type'] ) ? $options['paypal_receipt_type'] : '0';
			$this->paypal_customer_id      = isset( $options['paypal_customer_id'] ) ? $options['paypal_customer_id'] : '';
			$this->paypal_sort_code        = isset( $options['paypal_sort_code'] ) ? $options['paypal_sort_code'] : '100';
			$this->paypal_exempt_sort_code = isset( $options['paypal_exempt_sort_code'] ) ? $options['paypal_exempt_sort_code'] : '150';
			$this->paypal_rivpayment_type  = isset( $options['paypal_rivpayment_type'] ) ? $options['paypal_rivpayment_type'] : '';
			$this->paypal_sign_pin         = isset( $options['paypal_sign_pin'] ) ? $options['paypal_sign_pin'] : '';
			$this->paypal_send_mail        = isset( $options['paypal_send_mail'] ) ? $options['paypal_send_mail'] : '';
			$this->paypal_create_customer  = isset( $options['paypal_create_customer'] ) ?: '';
			$this->bcc_email               = isset( $options['bcc_email'] ) ? $options['bcc_email'] : '';
			$this->language                = isset( $options['document_language'] ) ? $options['document_language'] : 'he';
			$this->use_shipping_fields     = isset( $options['use_shipping_fields'] ) ? $options['use_shipping_fields'] : 'no';
			$this->logging                 = false;
			if ( isset( $options['do_logging'] ) ) {
				if ( $options['do_logging'] === 'yes' ) {
					$this->logging = true;
				}
			}
			$this->end_points = array(
				'url_invoice' => 'https://api.rivhit.co.il/online/RivhitOnlineAPI.svc/Document.New',
				'url_receipt' => "https://api.rivhit.co.il/online/RivhitOnlineAPI.svc/Receipt.New",
			);
			if ( $this->logger === null ) {
				$this->logger = new WC_Logger();
			}
		}

		/**
		 * @return void
		 *
		 *security reasons
		 */
		private function __clone() {
		}

		/**
		 * @return WC_Gateway_ICredit_Paypal|null
		 */
		public static function getInstance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * @param $order_id
		 *
		 * @return void
		 */
		public function get_paypal_response( $order_id ) {
			if ( ! $order_id ) {
				$this->save_logs_paypal( 'rivhit-document', 'No Order - PayPal IPN Process', 2 );

				return;
			}
			//	$this->save_logs_paypal( 'rivhit-document', 'Order Id: ' . $order_id, 2 );
			$resp = wc_get_order( $order_id );
			if ( ! empty( $resp ) ) {
				//	$this->save_logs_paypal( 'rivhit-document', 'Order Exists.', 2 );
				$data = $resp->get_data();
				$tid  = $data['transaction_id'];
				//	$this->save_logs_paypal( 'rivhit-document', 'data: ' . print_r( $data, true ), 2 );
				if ( $data['payment_method'] == "ppcp-gateway" && ! empty( $tid ) ) {
					$this->save_logs_paypal( 'rivhit-document', 'ORDER ID: ' . $order_id, 2 );
					$this->save_logs_paypal( 'rivhit-document', 'START PayPal IPN Process', 2 );
					$params = $this->get_data_from_website_for_ipn_or_webhook( $order_id );

					$this->save_logs_paypal( 'rivhit-document', 'paypal_document_type: ' . $this->paypal_document_type, 2 );
					$this->save_logs_paypal( 'rivhit-document', 'paypal_receipt_type: ' . $this->paypal_receipt_type, 2 );

					if ( $this->paypal_document_type != '0' ) {
						$this->call_to_rivhit_api( $order_id, $this->end_points['url_invoice'], $this->create_invoice_document( $params ), 'rivhit_document_url' );
					}
					if ( $this->paypal_receipt_type != '0' ) {
						$this->call_to_rivhit_api( $order_id, $this->end_points['url_receipt'], $this->create_receipt_document( $params ), 'rivhit_receipt_url' );
					}
				}
			}
		}

		/**
		 * @param $post
		 * Recieve and transmit PayPal IPN to iCredit
		 */
		public function icredit_valid_paypal_standard_ipn_request( $post ) {
			if ( ! $this->handle_paypal_ipn ) {
				$this->save_logs_paypal( 'rivhit-document', 'Not Valid PayPal IPN!', 2 );

				return true;
			}
			$this->save_logs_paypal( 'rivhit-document', 'Valid PayPal IPN received', 2 );

			/* Filter out other PayPal Payments */
			$json_custom_fields = json_decode( $post['custom'] );
			$this->save_logs_paypal( 'rivhit-document', 'Custom Fields: ' . print_r( $json_custom_fields, true ) );
			if ( ! isset( $json_custom_fields->order_key ) || ( strpos( $json_custom_fields->order_key, 'wc_order' ) === false ) ) {
				$this->save_logs_paypal( 'rivhit-document', 'EXIT: NO order_key', 2 );

				return false;
			}
			/* Exit if PayPal payments should not be integrated */
			if ( ! $this->handle_paypal_ipn || ! $this->paypal_api_token ) {
				$this->save_logs_paypal( 'rivhit-document', 'Requested not to handle IPN --OR-- NO paypal_api_token', 2 );

				return false;
			}
			$this->save_logs_paypal( 'rivhit-document', 'START PayPal IPN Process', 2 );
			$order_id = $json_custom_fields->order_id;
			$this->save_logs_paypal( 'rivhit-document', 'ORDER ID: ' . $order_id, 2 );
			$received_values = $this->get_paypal_data_ipn( $post );
			if ( $this->paypal_document_type != '0' ) {
				$this->call_to_rivhit_api( $order_id, $this->end_points['url_invoice'], $this->create_invoice_document( $received_values ), 'rivhit_document_url' );
			}
			if ( $this->paypal_receipt_type != '0' ) {
				$this->call_to_rivhit_api( $order_id, $this->end_points['url_receipt'], $this->create_receipt_document( $received_values ), 'rivhit_receipt_url' );
			}
		}

		/**
		 * @param $params
		 *
		 * @return array
		 */
		protected function create_receipt_document( $params ) {
			$data     = array(
				'api_token'         => $this->paypal_api_token,
				'receipt_type'     => $this->paypal_receipt_type,
				'customer_id'       => $params['customer_id'],
				'create_customer'   => trim( $this->paypal_create_customer ),
				'find_by_mail'      => true,
				'find_by_phone'     => true,
				'find_by_id'        => true,
				'last_name'         => $params['first_name'],
				'first_name'        => $params['last_name'],
				'currency_id'       => $params['mc_currency'],
				'address'           => $params['address_street'] ? $params['address_street'] : '',
				'country'           => $params['address_country_code'],
				'city'              => $params['address_city'] ? $params['address_city'] : '',
				'phone'             => (string)$params['phone'],
				'digital_signature' => true,
				'signature_pin'     => trim( $this->paypal_sign_pin ),
				'send_mail'         => trim( $this->paypal_send_mail ),
				'email_to'          => $params['payer_email'],
				'email_bcc'         => trim( $this->bcc_email ),
				'comments'          => $params['comment']
			);
			if ( !empty( $params['payer_business_name'] ) ) {
				$data['last_name'] .= ' ' . $params['payer_business_name'];
			}
			$lang = $this->icredit_helper_document_lang( $this->language, $params['address_country_code'] );
			if ( !empty( $lang ) ) {
				$data['language'] = $lang;
			}
			if ( !empty( $params['address_zip'] ) ) {
				$data['zipcode'] = (INT)$params['address_zip'];
			}
			if ( $params['mc_currency'] != '1' ) {
				$data['payments'] = array(
					array(
						'payment_type' => $this->paypal_rivpayment_type,
						'description'  => 'Paypal',
						'amount_mtc'  => ( number_format( (string) $params['mc_gross'], 2 ) )
					)
				);
			} else {
				$data['payments'] = array(
					array(
						'payment_type' => $this->paypal_rivpayment_type,
						'description'  => 'Paypal',
						'amount_nis'  => ( number_format( (string) $params['mc_gross'], 2 ) )
					)
				);
			}
			$jsonData = json_encode( $data );

			return [
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array( 'Content-Type' => 'application/json; charset=UTF-8' ),
				'body'        => $jsonData,
				'cookies'     => array()
			];
		}

		/**
		 * @param $params
		 *
		 * @return array
		 */
		protected function create_invoice_document( $params ) {
			$data     = array(
				'api_token'            => trim( $this->paypal_api_token ),
				'document_type'        => trim( $this->paypal_document_type ),
				'customer_id'          => $params['customer_id'],
				'last_name'            => $params['first_name'],
				'first_name'           => $params['last_name'],
				'address'              => $params['address_street'],
				'country'              => $params['address_country_code'],
				'city'                 => $params['address_city'],
				'phone'                => (string)$params['phone'],
				'create_customer'      => trim( $this->paypal_create_customer ),
		        'find_by_mail'         => true,
				'find_by_phone'        => true,
				'find_by_id'           => true,
				'price_include_vat'    => true,
				'currency_id'          => $params['mc_currency'],
				'order'                => $params['order'],
				'comments'             => $params['comment'],
				'digital_signature'    => true,
				'signature_pin'        => trim( $this->paypal_sign_pin ),
				'send_mail'            => trim( $this->paypal_send_mail ),
				'email_to'             => $params['payer_email'],
				'email_bcc'            => trim( $this->bcc_email ),
				'discount_type'        => 2,
				'discount_value'       => $params['discount'],
				'items'                => $params['items'],
			);
			if ( !empty( $params['payer_business_name'] ) ) {
				$data['last_name'] .= ' ' . $params['payer_business_name'];
			}
			$this->save_logs_paypal( 'rivhit-document', 'address_country_code: ' . $params['address_country_code'], 2);
			$this->save_logs_paypal( 'rivhit-document', 'sort_code: ' . $this->paypal_sort_code, 2);
			$this->save_logs_paypal( 'rivhit-document', 'exempt_sort_code: ' . $this->paypal_exempt_sort_code, 2);

			/*
						$vat = $this->rivhit_helper_exempt_vat( $this->paypal_sort_code , $this->paypal_exempt_sort_code , $params['address_country_code'] );
						if ( !empty( $vat ) ) {
							$data['sort_code'] = $vat;
							$this->save_logs_paypal( 'rivhit-document', 'data_sort_code: ' . $data['sort_code'], 2);
						}

			*/
			$data['sort_code'] = 100;

			if( $params['address_country_code'] == 'IL'){
				$data['sort_code'] = $this->paypal_sort_code;
			}
			else{
				$data['sort_code'] = $this->paypal_exempt_sort_code;
			}



			$lang = $this->icredit_helper_document_lang( $this->language, $params['address_country_code'] );
			if ( !empty( $lang ) ) {
				$data['language'] = $lang;
			}
			if ( !empty( $params['address_zip'] ) ) {
				$data['zipcode'] = (INT)$params['address_zip'];
			}
			if ( $params['mc_currency'] != '1' ) {
				$data['payments'] = array(
					array(
						'payment_type' => $this->paypal_rivpayment_type,
						'description'  => 'Paypal',
						'amount_mtc'  => ( number_format( (string) $params['mc_gross'], 2 ) )
					)
				);
			} else {
				$data['payments'] = array(
					array(
						'payment_type' => $this->paypal_rivpayment_type,
						'description'  => 'Paypal',
						'amount_nis'  => ( number_format( (string) $params['mc_gross'], 2 ) )
					)
				);
			}
			$jsonData = json_encode( $data );

			return [
				'method'      => 'POST',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array( 'Content-Type' => 'application/json; charset=UTF-8' ),
				'body'        => $jsonData,
				'cookies'     => array()
			];
		}


		/**
		 * @param $post
		 * @param $bool
		 *
		 * @return array
		 */
		private function get_paypal_data_ipn( $post, $bool = false ) {
			$response = [];
			if ( $bool === true ) {
				$response = stripslashes_deep( $post );
			} else {
				$invoice = $post['invoice'];
				$custom  = $post['custom']; // order id
				if ( ! empty( $custom ) ) {
					$custom   = json_decode( $custom );
					$order_id = $custom['order_id'];
					if ( ! empty( $order_id ) ) {
						$response = $this->get_data_from_website_for_ipn_or_webhook( $order_id, $post );
					}
				} else {
					if ( ! empty( $invoice ) ) {
						$prx      = 'WC-';
						$order_id = str_replace( $prx, '', $invoice );
						if ( ! empty( $order_id ) ) {
							$response = $this->get_data_from_website_for_ipn_or_webhook( $order_id, $post );
						}
					}
				}
			}

			return $response;
		}

		/**
		 * @param $order_id
		 * @param $ipn
		 *
		 * @return array
		 */
		private function get_data_from_website_for_ipn_or_webhook( $order_id, $ipn = array() ) {
			$res   = [];
			$order = new WC_Order( $order_id );
			if ( $order ) {
				// use billing or shipping

				$this->save_logs_paypal( 'rivhit-document', 'get_billing_country: ' . $order->get_billing_country(), 2);
				$this->save_logs_paypal( 'rivhit-document', 'get_billing_postcode: ' . $order->get_billing_postcode(), 2);
				$this->save_logs_paypal( 'rivhit-document', 'get_shipping_country: ' . $order->get_shipping_country(), 2);
				$this->save_logs_paypal( 'rivhit-document', 'get_shipping_postcode: ' .  $order->get_shipping_postcode(), 2);

				if ( $this->use_shipping_fields != 'yes' ) {
					$address      = $order->get_billing_address_1() . ' ' . $order->get_billing_address_2();
					$country      = $order->get_billing_country();
					$state        = $order->get_billing_state();
					$city         = $order->get_billing_city();
					$country_code = $order->get_billing_country();
					$zip          = $order->get_billing_postcode();
					$company_name = $order->get_billing_company();
					$first_name   = $order->get_billing_first_name();
					$last_name    = $order->get_billing_last_name();
					$phone        = $order->get_billing_phone();
				} else {
					$address      = $order->get_shipping_address_1() . ' ' . $order->get_shipping_address_2();
					$country      = $order->get_shipping_country();
					$state        = $order->get_shipping_state();
					$city         = $order->get_shipping_city();
					$country_code = $order->get_shipping_country();
					$zip          = $order->get_shipping_postcode();
					$company_name = $order->get_shipping_company();
					$first_name   = $order->get_shipping_first_name();
					$last_name    = $order->get_shipping_last_name();
					// in case there is no shipping phone
					$phone        = $order->get_billing_phone();
				}
				$zip = preg_replace( '/[^0-9.]+/', '', $zip );
				if ( !is_numeric( (int)$zip ) ) {
					$zip = '';
				}
				$res['order']                = $order_id;
				$res['customer_id']          = $this->paypal_customer_id;
				$res['email_to']             = $order->get_billing_email();
				$res['mc_gross']             = $this->clear_price_comma( $order->get_total() );
				$res['tax']                  = $this->clear_price_comma( $order->get_total_tax() );
				$res['address_street']       = $address;
				$res['payment_date']         = $order->get_created_via();
				$res['payment_status']       = 'Completed';
				$res['charset']              = 'UTF-8';
				$res['address_zip']          = $zip;
				$res['mc_shipping']          = $this->clear_price_comma( $order->get_shipping_total() );

				$this->save_logs_paypal( 'rivhit-document', 'get_shipping_total: ' . $res['mc_shipping'], 2 );

				$res['address_country_code'] = $country_code;
				$res['residence_country']    = $country_code;
				$res['address_country']      = $country;
				$res['address_state']        = $state;
				$res['address_city']         = $city;
				$res['payer_email']          = $order->get_billing_email();
				$res['payer_business_name']  = $company_name;
				$res['first_name']           = $first_name;
				$res['last_name']            = $last_name;
				$res['discount']             = $this->clear_price_comma( $order->get_discount_total() );
				$res['mc_currency']          = $this->icredit_helper_get_currency( $order->get_currency() );
				$res['shipping_method']      = $order->get_shipping_method();

				$this->save_logs_paypal( 'rivhit-document', 'shipping_method: ' . $res['shipping_method'], 2 );

				$this->save_logs_paypal( 'rivhit-document', 'Discount: ' . $res['discount'], 2 );

				if ( ! empty( $ipn ) ) {
					if ( isset( $ipn['ipn_track_id'] ) ) {
						$res['ipn_track_id']           = $ipn['ipn_track_id'];//get from IPN
					}
					if ( isset( $ipn['payer_id'] ) ) {
						$res['payer_id'] = $ipn['payer_id'];//get from IPN
					}
					if ( isset( $ipn['protection_eligibility'] ) ) {
						$res['protection_eligibility'] = $ipn['protection_eligibility'];//get from IPN
					}
					if ( isset( $ipn['address_name'] ) ) {
						$res['address_name'] = $ipn['address_name'];//get from IPN
					}
				}
				$res['num_cart_items']     = $order->get_item_count();
				$res['phone']              = $phone;
				if ( isset( $ipn['ipn_track_id'] ) ) {
					$res['request_reference'] = $ipn['ipn_track_id'];
				}
				$res['prevent_duplicates'] = true;
				$res['items']              = $this->get_items_from_order( $order, $order->get_currency() );
				$res['tid']                = get_post_meta( $order_id, '_transaction_id', true );
				$res['comment']            = $order->get_customer_note();
				$res['comment']           .= ' transaction_id: ' . $res['tid'] . ' WC-' . $res['order'] ;
			}

			return $res;
		}

		/**
		 * @param $order
		 * @param $order_id
		 *
		 * @return void
		 */
		public function set_webhook_paypal_payments_order( $order, $order_id ) {
			$this->save_logs_paypal( 'rivhit-document', 'START PayPal Payments Webhook Process', 2 );
			$this->save_logs_paypal( 'rivhit-document', 'ORDER ID: ' . $order_id, 2 );
			if ( $order->get_status() !== 'on-hold' ) {
				$this->save_logs_paypal( 'rivhit-document', 'status on hold', 2 );
				return;
			}
			$received_values = $this->get_data_from_website_for_ipn_or_webhook( $order_id );
			if ( $this->paypal_document_type != '0' ) {
				$this->call_to_rivhit_api( $order_id, $this->end_points['url_invoice'], $this->create_invoice_document( $received_values ), 'rivhit_document_url' );
			}
			if ( $this->paypal_receipt_type != '0' ) {
				$this->call_to_rivhit_api( $order_id, $this->end_points['url_receipt'], $this->create_receipt_document( $received_values ), 'rivhit_receipt_url' );
			}
		}

		/**
		 * @param $order
		 * @param $currency
		 *
		 * @return array
		 */
		private function get_items_from_order( $order, $currency ) {
			$items       = [];
			$order_items = $order->get_items();
			if ( ! empty( $order_items ) ) {
				foreach ( $order_items as $order_item ) {
					$line_total = ( $order_item['line_tax'] > 0 ) ? number_format( ( $order_item['subtotal'] + $order_item['line_tax'] ) / $order_item['qty'], 2 ) : number_format( $order_item['subtotal'] / $order_item['qty'], 2 );
					$line_total = $this->clear_price_comma( $line_total );
					/* Fix for variation SKU */
					if ( $order_item['variation_id'] ) {
						$temp_product = new WC_Product_Variation( $order_item['variation_id'] );
						array_push( $items, $this->icredit_massive_product_loop_arr( $temp_product, $line_total, $order_item, $currency ) );
						$attributes = $temp_product->get_variation_attributes();
						if ( count( $attributes ) ) {
							foreach ( $attributes as $key => $value ) {
								$key = str_replace( 'attribute_', '', $key );
								$key = str_replace( 'pa_', '', $key );
								array_push( $items, $this->icredit_massive_product_loop_arr_attr( $key, $value, $currency ) );
							}
						}
					} else {
						$temp_product = new WC_Product( $order_item['product_id'] );
						array_push( $items, $this->icredit_massive_product_loop_arr( $temp_product, $line_total, $order_item, $currency ) );
					}
				}
			}

			#ADD SHIPPING COSTS
			$shipping_total = $this->clear_price_comma( $order->get_shipping_total() );
			//$shipping_name =  $order->get_shipping_method();
			if ( $shipping_total <> 0 ) {
				$this->save_logs_paypal( 'rivhit-document', 'Go to shipping function' );
				array_push( $items, $this->icredit_massive_product_loop_arr_shipping( $order, $currency ) );
			}

			$this->save_logs_paypal( 'rivhit-document', 'Items array with shipping: ' . print_r( $items, true ) );

			return $items;
		}

		/**
		 * @param $temp_product
		 * @param $line_total
		 * @param $order_item
		 * @param $currency
		 *
		 * @return array
		 */
		private function icredit_massive_product_loop_arr( $temp_product, $line_total, $order_item, $currency ) {
			$arr = array(
				'item_id'        => '0',
				'catalog_number' => $temp_product->get_sku(),
				'quantity'       => $order_item['qty'],
				'description'    => $order_item['name']
			);
			if ( $currency !== 'ILS' ) {
				$arr['price_mtc'] = $this->clear_price_comma( $line_total );
			} else {
				$arr['price_nis'] = $this->clear_price_comma( $line_total );
			}

			return $arr;
		}

		/**
		 * @param $key
		 * @param $value
		 * @param $currency
		 *
		 * @return string[]
		 */
		private function icredit_massive_product_loop_arr_attr( $key, $value, $currency ) {
			$arr = array(
				'item_id'        => '0',
				'catalog_number' => '0',
				'quantity'       => '1',
				'description'    => urldecode( $key ) . ': ' . urldecode( $value )
			);
			if ( $currency !== 'ILS' ) {
				$arr['price_mtc'] = '0';
			} else {
				$arr['price_nis'] = '0';
			}
			return $arr;
		}


		/**
		 *
		 * @param $order
		 *
		 * @param $currency
		 *
		 * @return array
		 */
		private function icredit_massive_product_loop_arr_shipping( $order, $currency ) {
			$arr = array(
				'item_id'        => '0',
				//'catalog_number' => $temp_product->get_sku(),
				'quantity'       => 1,
				'description'    => $order->get_shipping_method()
			);
			if ( $currency !== 'ILS' ) {
				$arr['price_mtc'] = $this->clear_price_comma( $order->get_shipping_total() );
			} else {
				$arr['price_nis'] = $this->clear_price_comma( $order->get_shipping_total() );
			}
			$this->save_logs_paypal( 'rivhit-document', 'shipping array: ' . json_encode( $arr ), 2 );

			return $arr;
		}


		/**
		 * @param $order
		 *
		 * @return array
		 */
		private function get_items_from_order_old( $order ) {
			$items       = [];
			$order_items = $order->get_items();
			if ( ! empty( $order_items ) ) {
				foreach ( $order_items as $k => $order_item ) {
					$line_total = ( $order_item['line_tax'] > 0 ) ? number_format( ( $order_item['subtotal'] + $order_item['line_tax'] ) / $order_item['qty'], 2 ) : number_format( $order_item['subtotal'] / $order_item['qty'], 2 );
					$k ++;
					$items[ 'item_name' . $k ] = $order_item['name'];
					$items[ 'quantity' . $k ]  = $order_item['qty'];
					$items[ 'mc_gross_' . $k ] = $line_total;
				}
			}

			return $items;
		}





		/**
		 * @param $order_id
		 * @param $url
		 * @param $jsonData
		 * @param $key
		 *
		 * @return false
		 */
		private function call_to_rivhit_api( $order_id, $url, $jsonData, $key ) {
			$this->save_logs_paypal( 'rivhit-document', 'Before Send Params:' . print_r( $jsonData, true ) );
			$this->save_logs_paypal( 'rivhit-document', 'Before Send Key:' . $key, 2 );

			$getter = get_post_meta( $order_id, 'paypal_rivhit_doc_request', true );
			if ( ! empty( $getter ) ) {
				return false;
			}
			$response = wp_remote_post( $url, $jsonData ); // request for rivhit API.
			if ( is_wp_error( $response ) ) {
				$this->save_logs_paypal( 'rivhit-document', 'Error Response: ' . print_r( $response, true ) );

				return false;
			}
			$this->save_logs_paypal( 'rivhit-document', 'Body Response - order id: ' . $order_id );
			$this->save_logs_paypal( 'rivhit-document', 'Body Response: ' . print_r( $response, true ) );
			if ( ! empty( $response ) ) {
				$json_response = json_decode( $response['body'] );
				$this->update_order_data_paypal( $order_id, $key, $json_response->data->document_link );
			}
			update_post_meta( $order_id, 'paypal_rivhit_doc_request', '1' );

			return $response;
		}

		/**
		 * @param $order_id
		 * @param $key
		 * @param $data
		 *
		 * @return void
		 */
		private function update_order_data_paypal( $order_id, $key, $data ) {
			update_post_meta( $order_id, $key, $data );
		}

		/**
		 * @param $key
		 * @param $string
		 * @param $type
		 *
		 * @return void
		 */
		private function save_logs_paypal( $key = '', $string = '', $type = 1 ) {
			if ( ! empty( $key ) && ! empty( $string ) || ! empty( $key ) && ! empty( $string ) && $this->logging && $type == 2 ) {
				$this->logger->add( $key, $string );
			}
		}

		/**
		 * @param $lang
		 * @param $billing_country
		 *
		 * @return mixed|string
		 */
		private function icredit_helper_document_lang( $lang, $billing_country = 'IL' ) {
			switch ( $lang ) {
				case 'always_hebrew':
					$lang = 'he';
					break;
				case 'always_english':
					$lang = 'en';
					break;
				case 'by_country_code':
					if ( ! empty( $billing_country ) ) {
						switch ( $billing_country ) {
							case 'IL':
								$lang = 'he';
								break;
							case 'US':
								$lang = 'en';
								break;
							default:
								$lang = 'en';
								break;
						}
					} else {
						$lang = '';
					}
					break;
			}

			return $lang;
		}


		/**
		 * @param $sort_code
		 * @param $exempt_sort_code
		 * @param $country_code
		 *
		 * @return mixed|string
		 */
		private function rivhit_helper_exempt_vat( $sort_code, $exempt_sort_code, $country_code ) {
			$code = "100";

			if( $country_code == 'IL'){
				$code = $sort_code;
			}
			else{
				$code = $exempt_sort_code;
			}

			return $code;
		}


		/**
		 * @param $currency
		 *
		 * @return mixed|string
		 */
		function icredit_helper_get_currency( $currency = '' ) {
			switch ( $currency ) {
				case "ILS":
					$currency = "1";
					break;
				case "USD":
					$currency = "2";
					break;
				case "EUR":
					$currency = "3";
					break;
				case "GBP":
					$currency = "4";
					break;
				case "AUD":
					$currency = "5";
					break;
				case "CAD":
					$currency = "6";
					break;
				default:
					$currency = "";
					break;
			}

			return $currency;
		}

		/**
		 * @param $price
		 *
		 * @return array|string|string[]
		 */
		private function clear_price_comma( $price ) {
			$price = (string)$price;
			if ( !empty( $price ) ) {
				$price = str_replace(',', '', $price);
			}
			return $price;
		}



	}

	$self_class_icredit_paypal = WC_Gateway_ICredit_Paypal::getInstance();
}
