<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
/*
 * Plugin Name: Woocommerce Rivhit Documents
 * Description: standalone plugin for paypal documents by Icredit
 * Version: 4.0.0
 * Author: rivhit
 * Author URI: https://www.rivhit.co.il/
 * Requires at least: 5.7
 * Tested up to: 6.0
 * License: GPLv2 or later
 * Text Domain: woocommerce icredit paypal
 */

/**
 * iCredit class
 */
class iCredit_Paypal {
	/**
	 * @var string
	 */
	public $plugin_url;

	/**
	 * @var string
	 */
	public $plugin_path;

	public function __construct() {
		define( 'RIVHIT_PAYPAL_VERSION', '1.0.0' );
		$this->plugin_path = plugin_dir_path(__FILE__);
		define('ICREDIT_PAYPAL_PLUGIN_URL', plugins_url('/', __FILE__));
		add_action( 'woocommerce_loaded', array( $this, 'load_plugin_methods') );
		add_action( 'admin_menu', [ $this, 'rivhit_paypal_admin_menu' ], 5 );
		add_action('admin_enqueue_scripts', [ 'Icredit_Admin_Fields_Paypal', 'rivhit_paypal_admin_enqueue' ] );
	}

	/**
	 * @return void
	 */
	public function load_plugin_methods() {
		load_plugin_textdomain('woocommerce_icredit_paypal', false, dirname( plugin_basename( __FILE__ ) ) . "/languages");
		require_once 'core/Icredit_Admin_Fields_Paypal.class.php';
		require_once 'core/Icredit_Admin_Docs.class.php';
		require_once 'core/WC_Gateway_ICredit_Paypal.class.php';

		/* Load PayPal IPN */
		$icreditPaypal = WC_Gateway_ICredit_Paypal::getInstance();

		// front end issue
		add_action('woocommerce_thankyou', function($order) use ( $icreditPaypal ) { $icreditPaypal->get_paypal_response( $order ); }, 10, 1);
		//ipn method
		add_action( "valid-paypal-standard-ipn-request", [ $icreditPaypal, 'icredit_valid_paypal_standard_ipn_request' ], 10, 1 );
		//paypal express
		add_action( "valid-paypal-standard-ipn-request", function($post) use ( $icreditPaypal ) {
			$icreditPaypal->icredit_valid_paypal_standard_ipn_request($post);
		}, 10, 1 );	
		//paypal checkout
		add_action( "woocommerce_paypal_express_checkout_valid_ipn_request", function ($post) use ( $icreditPaypal ) {
			$icreditPaypal->icredit_valid_paypal_standard_ipn_request($post);
		}, 10, 1 );
	}


	/**
	 * Get the plugin url.
	 *
	 * @access public
	 * @return string
	 */
	public function plugin_url() {
		if ( $this->plugin_url ) return $this->plugin_url;
		return $this->plugin_url = ICREDIT_PAYPAL_PLUGIN_URL;
	}

	/**
	 * @return void
	 */
	public function rivhit_paypal_admin_menu() {
		add_menu_page(
			__( 'Rivhit Documents', "woocommerce_icredit_paypal" ),
			__( "Rivhit Documents", "woocommerce_icredit_paypal" ),
			'manage_options',
			'page-memberships',
			[ $this, 'cj_render_page_icredit_paypal_options' ],
			'dashicons-media-document',
			20
		);
	}

	/**
	 * @return void
	 */
	public function cj_render_page_icredit_paypal_options() {
		global $title;
		print '<div class="wrap" id="rivhit_paypa_icredit_wrapper">';
		print "<div class='logoIcredit'><picture><img src='" . ICREDIT_PAYPAL_PLUGIN_URL . "/assets/images/Rivhit2.png' alt='logo rivhit' aria-label='logo rivhit' width='130' height='50'/></picture></div>";
		print "<h1>$title</h1><hr/>";
		include_once $this->plugin_url . 'admin/icredit-paypal-options.php';
		print '</div>';
	}

	/**
	 * @param $wc_order
	 * @param $order_id
	 *
	 * @return void
	 */
	public function rivhit_paypal_payments_webhook_listener( $wc_order, $order_id ) {
		$icreditPaypal = WC_Gateway_ICredit_Paypal::getInstance();
		$icreditPaypal->set_webhook_paypal_payments_order( $wc_order, $order_id );
	}

}

$GLOBALS['icredit_paypal'] = new iCredit_Paypal();
?>
